import { IPermission, IRole, PermissionsObject, extendOpts, permission, permissions } from '../types';
/**
 * Role class
 */
export default class Role implements IRole {
    permissions: IPermission[];
    /**
     * Role constructor
     */
    constructor(permissions?: IPermission[]);
    private formatPermission;
    addPermission(permission: IPermission): this;
    removePermission(resource: string): this;
    updatePermission(permission: IPermission): this;
    canCreate(resource: string): boolean;
    canRead(resource: string): boolean;
    canUpdate(resource: string): boolean;
    canDelete(resource: string): boolean;
    canList(resource: string): boolean;
    can(permission: permission, resource: string): boolean;
    canAny(permissions: permissions, resource: string): boolean;
    canAll(permissions: permissions, resource: string): boolean;
    extend(role: IRole, options?: extendOpts): this;
    generate(format?: 'json' | 'object'): string | PermissionsObject;
    toJSON(): string;
    toObject(): PermissionsObject;
    /**
     * Load a role from a json string
     * @param json - Json string to load
     */
    static fromJSON(json: string): Role;
    /**
     * Load a role from a javascript object
     * @param object - Object to load
     */
    static fromObject(o: PermissionsObject): Role;
    static validate(role: IRole, cb?: (result: boolean, error?: Error) => void): boolean;
    static validatePermission(permission: IPermission): boolean;
    getResources(): string[];
}
